@@ -5,7 +5,7 @@ use 5.008001;
 use strict;
 use warnings;
 
-our $VERSION = '0.001_002';
+our $VERSION = '0.001_003';
 $VERSION = eval $VERSION;   ## no critic (BuiltinFunctions::ProhibitStringyEval)
 
 ## no critic (RequirePodAtEnd)
@@ -18,7 +18,7 @@ Array::2D - Methods for simple array-of-arrays data structures
 
 =head1 VERSION
 
-This documentation refers to version 0.001_002
+This documentation refers to version 0.001_003
 
 =head2 NOTICE
 
@@ -2590,6 +2590,10 @@ Some other modules that have some similarities include:
 
 =over
 
+=item L<Data::CTable|Data::CTable>
+
+=item L<Data::ShowTable|Data::ShowTable>
+
 =item L<Data::Table|Data::Table>
 
 =item L<PDL|PDL>
@@ -2600,6 +2604,9 @@ Some other modules that have some similarities include:
 
 These all appear much more powerful than Array::2D and may better suit your use.
 
+Another relevant module is L<Data::ShowTable|Data::ShowTable>, 
+which creates output formats such as ASCII art boxes and HTML.
+
 =head1 DEPENDENCIES
 
 =over
